#!/bin/bash

SCRIPT_FULL_NAME=$(readlink -e $0)
MYDIR=$(dirname $SCRIPT_FULL_NAME)
MYNAME=$(basename $SCRIPT_FULL_NAME)

cd "$MYDIR" || exit 1

echo "Creating virtual environment for python."
python -m venv VENV

echo "Activate virtual environment."
source VENV/bin/activate

echo "Installing sumo."
pip install epics-sumo

echo "Creating sumo.config."
sumo config new SUMO github
sumo config make sumo.config --yes --#opt-preload configure/MODULES --#opt-preload configure/MODULES.HOST

echo "Add additional sumo dependency database entries for MultiCAN."
sumo db merge templates/EXTRA.DB

echo "Building EPICS base, please be patient..."
sleep 1
sumo build new BASE:R3-15-9 --makeflags "-sj" --progress

# define BASE environment variable:
eval "$(sumo build use BASE:R3-15-9 -o - | sed -e 's/^EPICS_//')"

echo "EPICS Base is in $BASE."

# set environment variables to use that EPICS base:
source $BASE/setenv.sh

echo "Creating ioc with makeBaseApp.pl."
makeBaseApp.pl -b $EPICS_BASE -t ioc socanTest
makeBaseApp.pl -i -t ioc -p socanTest iocsocanTest

echo "Configure IOC for MultiCAN."
cp -a templates/MODULES configure
cp -a templates/Db/* socanTestApp/Db
cp -a templates/src/* socanTestApp/src
cp -a templates/start-ioc.sh .
cp -a templates/boot/* iocBoot/iocsocanTest

echo "Building all support modules, please be patient."
sleep 1
sumo build new --makeflags "-sj" --progress

echo "Use support modules in ioc application."
sumo build use

echo "Now build the ioc."
make -sj

# define SOCAN environment variable:
eval "$(grep SOCAN configure/RELEASE)"

echo "Define virtual CAN interfaces, this requires sudo rights."
$SOCAN/bin/init-can.sh -d vcan

echo "Link first two CAN interfaces."
$SOCAN/bin/link-vcan-devices.sh link 0 1
echo

echo
echo "source $MYDIR/VENV/bin/activate" > setenv.sh
echo "eval \"\$(sumo help completion-line)\"" >> setenv.sh
echo "BASE=$BASE" >> setenv.sh
echo "source \$BASE/setenv.sh" >> setenv.sh
echo
echo "Finished, you may now start the ioc (requires sudo) with:"
echo "./start-ioc.sh"
echo
echo "In a second window you may enter:"
echo "  source ./setenv.sh"
echo "And then run for example:"
echo
echo "  camonitor ca1testo cantesto ca2testo cantesti"
echo
echo "This shows that the records are processed in the order:"
echo "  ca1testo : get counter, trigger can write"
echo "  cantesto : write to CAN bus, trigger ca2testo"
echo "  ca2testo : processed after CAN write"
echo "  cantesti : read from CAN bus, this comes last"
echo
echo "Second example: get timestamps, enter:"
echo "  camonitor cantesto_ts.VALA cantesti_ts.VALA"
echo
echo "This shows the human readable microsecond timestamp of"
echo "the CAN write and CAN read object."




